searchData={"items":[{"type":"module","title":"DG","doc":"Elixir wrapper of `:digraph` with a pinch of protocols and sigils","ref":"DG.html"},{"type":"module","title":"Installation - DG","doc":"The package can be installed by adding `dg` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:dg, \"~> 0.4\"},\n    ...\n  ]\nend\n```","ref":"DG.html#module-installation"},{"type":"module","title":"Highlights - DG","doc":"","ref":"DG.html#module-highlights"},{"type":"module","title":"Inspect - DG","doc":"```elixir\ndg = DG.new()\nDG.add_vertex(dg, \"v1\")\nDG.add_vertex(dg, \"v2\", \"label 2\")\nDG.add_vertex(dg, \"v3\")\nDG.add_edge(dg, \"v1\", \"v2\")\nDG.add_edge(dg, \"v1\", \"v3\", \"1 to 3\")\n\nIO.inspect(dg)\n```\n\nOutputs `mermaid.js` format flowchart\n\n```\ngraph LR\n    v1-->v2[label 2]\n    v1--1 to 3-->v3\n```\n\nwhich can be put into livebook `mermaid` block and will display as\n\n```mermaid\ngraph LR\n    v1-->v2[label 2]\n    v1--1 to 3-->v3\n```","ref":"DG.html#module-inspect"},{"type":"module","title":"Collectable - DG","doc":"Easily add\n\n- vertices `[{:vertex, 1}, {:vertex, 2, \"label 2\"}, ...]`\n- or edges `[{:edge, 1, 2}, {:edge, \"a\", \"b\", \"label ab\"}, ...]`\n\nto the graph via `Enum.into/2`\n\n```elixir\ndg = DG.new()\n\n~w(a b c d e) |> Enum.map(&{:vertex, &1}) |> Enum.into(dg)\n\n~w(a b c d e)\n|> Enum.chunk_every(2, 1, :discard)\n|> Enum.map(fn [f, t] -> {:edge, f, t} end)\n|> Enum.into(dg)\n\nIO.inspect(dg)\n```\n\noutputs\n\n```mermaid\ngraph LR\n    b-->c\n    c-->d\n    a-->b\n    d-->e\n```","ref":"DG.html#module-collectable"},{"type":"module","title":"Functions - DG","doc":"- Most functions from `:digraph` and `:digraph_utils` are mirrored under `DG`.\n- Some functions have their parameters re-arranged so that the graph is always the first parameter.\n  (namely `reachable/2`, `reachable_neighbours/2`, `reaching/2` and `reaching_neighbours/2`)\n- `new/{0,1,2,3}` returns `%DG{}` instead of an Erlang `digraph`\n- `new/2` and `new/3` are shortcuts that can add vertices and edges on creation,\n  which don't exist on `:digraph`","ref":"DG.html#module-functions"},{"type":"module","title":"Sigils - DG","doc":"`~G` and `~g` are provided so you can copy `mermaid.js` flowchart and paste into Elixir to get a `%DG{}`\n\n```elixir\nimport DG.Sigil\n\ndg = ~G\"\"\"\ngraph LR\n  a[some label]\n  b[other label]\n  1-->2\n  3[three] -- three to four --> 4[four]\n  a --> b\n\"\"\"\n```\n\n```elixir\n# With interpolation\n\nlabel = \"1 2 3\"\ndg = ~g\"\"\"\ngraph LR\n  a --#{label}--> b\n\"\"\"\n```\n\n**caveat:** `:digraph` is stateful (using `ets`), don't use the sigil at compile time,\ne.g. as a module attribute, it won't carry over to runtime.\nOnly use it in runtime code, e.g. function body,\nand remember to clean up properly when it's no longer used, with `delete/1`.","ref":"DG.html#module-sigils"},{"type":"module","title":"Load from `libgraph` - DG","doc":"```elixir\ndg = DG.new()\nDG.from({:libgraph, graph})\n```","ref":"DG.html#module-load-from-libgraph"},{"type":"function","title":"DG.add_edge/3","doc":"","ref":"DG.html#add_edge/3"},{"type":"function","title":"DG.add_edge/4","doc":"","ref":"DG.html#add_edge/4"},{"type":"function","title":"DG.add_edge/5","doc":"","ref":"DG.html#add_edge/5"},{"type":"function","title":"DG.add_vertex/1","doc":"","ref":"DG.html#add_vertex/1"},{"type":"function","title":"DG.add_vertex/2","doc":"","ref":"DG.html#add_vertex/2"},{"type":"function","title":"DG.add_vertex/3","doc":"","ref":"DG.html#add_vertex/3"},{"type":"function","title":"DG.arborescence_root/1","doc":"","ref":"DG.html#arborescence_root/1"},{"type":"function","title":"DG.components/1","doc":"","ref":"DG.html#components/1"},{"type":"function","title":"DG.condensation/1","doc":"","ref":"DG.html#condensation/1"},{"type":"function","title":"DG.cyclic_strong_components/1","doc":"","ref":"DG.html#cyclic_strong_components/1"},{"type":"function","title":"DG.del_edge/2","doc":"","ref":"DG.html#del_edge/2"},{"type":"function","title":"DG.del_edges/2","doc":"","ref":"DG.html#del_edges/2"},{"type":"function","title":"DG.del_path/3","doc":"","ref":"DG.html#del_path/3"},{"type":"function","title":"DG.del_vertex/2","doc":"","ref":"DG.html#del_vertex/2"},{"type":"function","title":"DG.del_vertices/2","doc":"","ref":"DG.html#del_vertices/2"},{"type":"function","title":"DG.delete/1","doc":"","ref":"DG.html#delete/1"},{"type":"function","title":"DG.edge/2","doc":"","ref":"DG.html#edge/2"},{"type":"function","title":"DG.edges/1","doc":"","ref":"DG.html#edges/1"},{"type":"function","title":"DG.edges/2","doc":"","ref":"DG.html#edges/2"},{"type":"function","title":"DG.from/1","doc":"","ref":"DG.html#from/1"},{"type":"function","title":"DG.get_cycle/2","doc":"","ref":"DG.html#get_cycle/2"},{"type":"function","title":"DG.get_path/3","doc":"","ref":"DG.html#get_path/3"},{"type":"function","title":"DG.get_short_cycle/2","doc":"","ref":"DG.html#get_short_cycle/2"},{"type":"function","title":"DG.get_short_path/3","doc":"","ref":"DG.html#get_short_path/3"},{"type":"function","title":"DG.in_degree/2","doc":"","ref":"DG.html#in_degree/2"},{"type":"function","title":"DG.in_edges/2","doc":"","ref":"DG.html#in_edges/2"},{"type":"function","title":"DG.in_neighbours/2","doc":"","ref":"DG.html#in_neighbours/2"},{"type":"function","title":"DG.info/1","doc":"","ref":"DG.html#info/1"},{"type":"function","title":"DG.is_acyclic/1","doc":"","ref":"DG.html#is_acyclic/1"},{"type":"function","title":"DG.is_arborescence/1","doc":"","ref":"DG.html#is_arborescence/1"},{"type":"function","title":"DG.is_tree/1","doc":"","ref":"DG.html#is_tree/1"},{"type":"function","title":"DG.loop_vertices/1","doc":"","ref":"DG.html#loop_vertices/1"},{"type":"function","title":"DG.new/1","doc":"","ref":"DG.html#new/1"},{"type":"function","title":"DG.new/2","doc":"","ref":"DG.html#new/2"},{"type":"function","title":"DG.new/3","doc":"","ref":"DG.html#new/3"},{"type":"function","title":"DG.no_edges/1","doc":"","ref":"DG.html#no_edges/1"},{"type":"function","title":"DG.no_vertices/1","doc":"","ref":"DG.html#no_vertices/1"},{"type":"function","title":"DG.options/1","doc":"","ref":"DG.html#options/1"},{"type":"function","title":"DG.options/2","doc":"","ref":"DG.html#options/2"},{"type":"function","title":"DG.out_degree/2","doc":"","ref":"DG.html#out_degree/2"},{"type":"function","title":"DG.out_edges/2","doc":"","ref":"DG.html#out_edges/2"},{"type":"function","title":"DG.out_neighbours/2","doc":"","ref":"DG.html#out_neighbours/2"},{"type":"function","title":"DG.postorder/1","doc":"","ref":"DG.html#postorder/1"},{"type":"function","title":"DG.preorder/1","doc":"","ref":"DG.html#preorder/1"},{"type":"function","title":"DG.reachable/2","doc":"","ref":"DG.html#reachable/2"},{"type":"function","title":"DG.reachable_neighbours/2","doc":"","ref":"DG.html#reachable_neighbours/2"},{"type":"function","title":"DG.reaching/2","doc":"","ref":"DG.html#reaching/2"},{"type":"function","title":"DG.reaching_neighbours/2","doc":"","ref":"DG.html#reaching_neighbours/2"},{"type":"function","title":"DG.strong_components/1","doc":"","ref":"DG.html#strong_components/1"},{"type":"function","title":"DG.subgraph/3","doc":"","ref":"DG.html#subgraph/3"},{"type":"function","title":"DG.topsort/1","doc":"","ref":"DG.html#topsort/1"},{"type":"function","title":"DG.vertex/2","doc":"","ref":"DG.html#vertex/2"},{"type":"function","title":"DG.vertices/1","doc":"","ref":"DG.html#vertices/1"},{"type":"module","title":"DG.Sigil","doc":"Sigils that parse `mermaid.js` format flowchart into `DG`\n\n    iex> import DG.Sigil\n    ...> dg = ~G\"\"\"\n    ...> graph LR\n    ...>   a[some label]\n    ...>   b[other label]\n    ...>   1-->2\n    ...>   3[three] -- three to four --> 4[four]\n    ...>   a --> b\n    ...> \"\"\"\n    iex> DG.vertex(dg, \"a\")\n    {\"a\", \"some label\"}\n    iex> Enum.sort(DG.vertices(dg))\n    [\"1\", \"2\", \"3\", \"4\", \"a\", \"b\"]\n    iex> length(DG.edges(dg))\n    3","ref":"DG.Sigil.html"},{"type":"function","title":"DG.Sigil.direction/2","doc":"Parses the given `binary` as direction.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the direction (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#direction/2"},{"type":"function","title":"Options - DG.Sigil.direction/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#direction/2-options"},{"type":"function","title":"DG.Sigil.edge/2","doc":"Parses the given `binary` as edge.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the edge (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#edge/2"},{"type":"function","title":"Options - DG.Sigil.edge/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#edge/2-options"},{"type":"function","title":"DG.Sigil.graph/2","doc":"Parses the given `binary` as graph.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the graph (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#graph/2"},{"type":"function","title":"Options - DG.Sigil.graph/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#graph/2-options"},{"type":"function","title":"DG.Sigil.label/2","doc":"Parses the given `binary` as label.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the label (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#label/2"},{"type":"function","title":"Options - DG.Sigil.label/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#label/2-options"},{"type":"function","title":"DG.Sigil.lwsp/2","doc":"Parses the given `binary` as lwsp.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the lwsp (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#lwsp/2"},{"type":"function","title":"Options - DG.Sigil.lwsp/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#lwsp/2-options"},{"type":"function","title":"DG.Sigil.parse/1","doc":"","ref":"DG.Sigil.html#parse/1"},{"type":"function","title":"DG.Sigil.parse!/1","doc":"","ref":"DG.Sigil.html#parse!/1"},{"type":"macro","title":"DG.Sigil.sigil_G/2","doc":"","ref":"DG.Sigil.html#sigil_G/2"},{"type":"macro","title":"DG.Sigil.sigil_g/2","doc":"","ref":"DG.Sigil.html#sigil_g/2"},{"type":"function","title":"DG.Sigil.square_brace_close/2","doc":"Parses the given `binary` as square_brace_close.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the square_brace_close (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#square_brace_close/2"},{"type":"function","title":"Options - DG.Sigil.square_brace_close/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#square_brace_close/2-options"},{"type":"function","title":"DG.Sigil.square_brace_open/2","doc":"Parses the given `binary` as square_brace_open.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the square_brace_open (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#square_brace_open/2"},{"type":"function","title":"Options - DG.Sigil.square_brace_open/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#square_brace_open/2-options"},{"type":"function","title":"DG.Sigil.type/2","doc":"Parses the given `binary` as type.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the type (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#type/2"},{"type":"function","title":"Options - DG.Sigil.type/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#type/2-options"},{"type":"function","title":"DG.Sigil.vertex/2","doc":"Parses the given `binary` as vertex.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the vertex (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#vertex/2"},{"type":"function","title":"Options - DG.Sigil.vertex/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#vertex/2-options"},{"type":"function","title":"DG.Sigil.vertex_id/2","doc":"Parses the given `binary` as vertex_id.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the vertex_id (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#vertex_id/2"},{"type":"function","title":"Options - DG.Sigil.vertex_id/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#vertex_id/2-options"},{"type":"function","title":"DG.Sigil.vertex_or_edge/2","doc":"Parses the given `binary` as vertex_or_edge.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the vertex_or_edge (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#vertex_or_edge/2"},{"type":"function","title":"Options - DG.Sigil.vertex_or_edge/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#vertex_or_edge/2-options"},{"type":"function","title":"DG.Sigil.wsp/2","doc":"Parses the given `binary` as wsp.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the wsp (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"DG.Sigil.html#wsp/2"},{"type":"function","title":"Options - DG.Sigil.wsp/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"DG.Sigil.html#wsp/2-options"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"},{"type":"extras","title":"v0.4.1 - CHANGELOG","doc":"Support non string labels, thanks @martosaur (#39)","ref":"changelog.html#v0-4-1"},{"type":"extras","title":"v0.4.0 - CHANGELOG","doc":"`subgraph` now returns a DG struct, thanks @jdewar ! (#25)","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.0 - CHANGELOG","doc":"Add loading from `:libgraph` `Graph`.","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.0 - CHANGELOG","doc":"Add interpolation support.","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.0 - CHANGELOG","doc":"[View highlights](https://github.com/princemaple/dg/blob/v0.1.0/README.md#highlights)","ref":"changelog.html#v0-1-0"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2022 Po Chen\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# DG\n\n<!-- DOC -->\n\nElixir wrapper of `:digraph` with a pinch of protocols and sigils","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"The package can be installed by adding `dg` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:dg, \"~> 0.4\"},\n    ...\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Highlights - Overview","doc":"","ref":"readme.html#highlights"},{"type":"extras","title":"Inspect - Overview","doc":"```elixir\ndg = DG.new()\nDG.add_vertex(dg, \"v1\")\nDG.add_vertex(dg, \"v2\", \"label 2\")\nDG.add_vertex(dg, \"v3\")\nDG.add_edge(dg, \"v1\", \"v2\")\nDG.add_edge(dg, \"v1\", \"v3\", \"1 to 3\")\n\nIO.inspect(dg)\n```\n\nOutputs `mermaid.js` format flowchart\n\n```\ngraph LR\n    v1-->v2[label 2]\n    v1--1 to 3-->v3\n```\n\nwhich can be put into livebook `mermaid` block and will display as\n\n```mermaid\ngraph LR\n    v1-->v2[label 2]\n    v1--1 to 3-->v3\n```","ref":"readme.html#inspect"},{"type":"extras","title":"Collectable - Overview","doc":"Easily add\n\n- vertices `[{:vertex, 1}, {:vertex, 2, \"label 2\"}, ...]`\n- or edges `[{:edge, 1, 2}, {:edge, \"a\", \"b\", \"label ab\"}, ...]`\n\nto the graph via `Enum.into/2`\n\n```elixir\ndg = DG.new()\n\n~w(a b c d e) |> Enum.map(&{:vertex, &1}) |> Enum.into(dg)\n\n~w(a b c d e)\n|> Enum.chunk_every(2, 1, :discard)\n|> Enum.map(fn [f, t] -> {:edge, f, t} end)\n|> Enum.into(dg)\n\nIO.inspect(dg)\n```\n\noutputs\n\n```mermaid\ngraph LR\n    b-->c\n    c-->d\n    a-->b\n    d-->e\n```","ref":"readme.html#collectable"},{"type":"extras","title":"Functions - Overview","doc":"- Most functions from `:digraph` and `:digraph_utils` are mirrored under `DG`.\n- Some functions have their parameters re-arranged so that the graph is always the first parameter.\n  (namely `reachable/2`, `reachable_neighbours/2`, `reaching/2` and `reaching_neighbours/2`)\n- `new/{0,1,2,3}` returns `%DG{}` instead of an Erlang `digraph`\n- `new/2` and `new/3` are shortcuts that can add vertices and edges on creation,\n  which don't exist on `:digraph`","ref":"readme.html#functions"},{"type":"extras","title":"Sigils - Overview","doc":"`~G` and `~g` are provided so you can copy `mermaid.js` flowchart and paste into Elixir to get a `%DG{}`\n\n```elixir\nimport DG.Sigil\n\ndg = ~G\"\"\"\ngraph LR\n  a[some label]\n  b[other label]\n  1-->2\n  3[three] -- three to four --> 4[four]\n  a --> b\n\"\"\"\n```\n\n```elixir\n# With interpolation\n\nlabel = \"1 2 3\"\ndg = ~g\"\"\"\ngraph LR\n  a --#{label}--> b\n\"\"\"\n```\n\n**caveat:** `:digraph` is stateful (using `ets`), don't use the sigil at compile time,\ne.g. as a module attribute, it won't carry over to runtime.\nOnly use it in runtime code, e.g. function body,\nand remember to clean up properly when it's no longer used, with `delete/1`.","ref":"readme.html#sigils"},{"type":"extras","title":"Load from `libgraph` - Overview","doc":"```elixir\ndg = DG.new()\nDG.from({:libgraph, graph})\n```","ref":"readme.html#load-from-libgraph"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}